@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.1.11'
+__version__ = '0.1.12'
 
 try:
     from importlib import import_module
@@ -33,7 +33,8 @@ from types import ModuleType
 
 LOGGER = getLogger(__name__)
 
-NEVER = 0
+AT_LEAST_ONCE = 'AT-LEAST-ONCE'
+NEVER = 'NEVER'
 
 _configurators = {}
 _patch_entries = []
@@ -305,8 +306,9 @@ class Verifier(FluentTarget):
         self._attribute_name = None
         self._times = times
 
-        if times not in [0, 1]:
-            raise NotImplementedError('Times can be 0 or 1.')
+        if times not in [NEVER, AT_LEAST_ONCE]:
+            error_message = 'Times can be {never} or {once}.'.format(never=NEVER, once=AT_LEAST_ONCE)
+            raise NotImplementedError(error_message)
 
     def __getattr__(self, name):
         self._attribute_name = name
@@ -383,5 +385,5 @@ def get_patches():
     return _patch_entries
 
 
-def verify(target, times=1):
+def verify(target, times=AT_LEAST_ONCE):
     return Verifier(target, times)
